# Last-Mile Aerial Routing (LAR) - Path Planning Algorithm

A demo can be found at [`presentation.ipynb`](https://github.com/wzjoriv/Larp/blob/main/presentation.ipynb).

![alt text](https://github.com/wzjoriv/Larp/blob/main/docs/imgs/route_graph.png?raw=true)